@@ -11,7 +11,9 @@ For to determine or to change the default language and message text encoding the
 functions :func:default_language` and :func:`default_encoding` are provided
 by this portion.
 
-For to specify other locale folders you can use the function :func:`add_paths`.
+For to specify other locale folders you can use the function :func:`add_paths`,
+which is calling :func:`init_installed_languages` for to prepare the loading
+of additional translations.
 
 In any locale folder have to exist one sub-folder with a name of the
 language code (e.g. 'en_US') for each supported language. In each of these
@@ -27,7 +29,7 @@ translatable message texts and f-strings
 
 Simple message texts can be enclosed in the code of your application with the
 :func:`get_text` function, which can also be imported with the underscore alias
-from this module::
+from this module (the function :func:`_`)::
 
     from ae.i18n import _
 
@@ -59,6 +61,8 @@ with the desired language code onto the call of :func:`get_text` (or :func:`get_
     print(_("message", language='es_ES'))   # returns the spanish translation text of "message"
     print(_("message", language='de_DE'))   # returns the german translation text of "message"
 
+The helper function :func:`translation` can be used for to determine if a translation exists for
+a message text.
 """
 import ast
 import locale
@@ -68,7 +72,7 @@ from typing import Any, Dict, List, Optional, Union
 from ae.core import stack_variables, try_eval           # type: ignore
 
 
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 
 MsgType = Union[str, Dict[str, str]]                    #: type of message translations within :data:`MSG_FILE_SUFFIX`
@@ -92,6 +96,24 @@ installed_languages: List[str] = list()                 #: list of all languages
 loaded_languages: Dict[str, LanguageMessages] = dict()  #: message text translations of all loaded languages
 
 
+def add_paths(*file_paths: str, reset: bool = False):
+    """ add/register new file paths for to search for language and region configurations.
+
+    The list of installed translation languages will automatically be updated.
+
+    :param file_paths:  tuple of locale folder root paths. Each folder path is containing
+                        sub-folders for each supported language/locale. The name of each
+                        sub is the language code of the locale (e.g. es_ES for Spain).
+    :param reset:       pass True for to clear all previously added paths.
+    """
+    global locale_paths
+    if reset:
+        # faster than locale_paths[:] = [] (https://stackoverflow.com/questions/850795/different-ways-of-clearing-lists)
+        locale_paths *= 0
+    locale_paths.extend(file_paths)
+    init_installed_languages()
+
+
 def default_language(new_lang: str = '') -> str:
     """ get and optionally set the default language code.
 
@@ -118,22 +140,17 @@ def default_encoding(new_enc: str = '') -> str:
     return old_enc
 
 
-def add_paths(*file_paths: str, reset: bool = False):
-    """ add/register new file paths for to search for language and region configurations.
-
-    The list of installed translation languages will automatically be updated.
-
-    :param file_paths:  tuple of locale folder root paths. Each folder path is containing
-                        sub-folders for each supported language/locale. The name of each
-                        sub is the language code of the locale (e.g. es_ES for Spain).
-    :param reset:       pass True for to clear all previously added paths.
+def init_installed_languages():
+    """ reset and rescan the configured/supported languages found in the currently set :data:`locale_paths`.
     """
-    global locale_paths
-    if reset:
-        # faster than locale_paths[:] = [] (https://stackoverflow.com/questions/850795/different-ways-of-clearing-lists)
-        locale_paths *= 0
-    locale_paths.extend(file_paths)
-    init_installed_languages()
+    global installed_languages
+    installed_languages *= 0
+
+    for path in locale_paths:
+        if os.path.exists(path):
+            installed_languages.extend(
+                dir_entry.name for dir_entry in os.scandir(path)
+                if dir_entry.is_dir() and os.path.exists(os.path.join(dir_entry.path, MSG_FILE_SUFFIX)))
 
 
 def load_language_texts(language: str, encoding: str = '', domain: str = '', reset: bool = False):
@@ -165,44 +182,39 @@ def load_language_texts(language: str, encoding: str = '', domain: str = '', res
                 loaded_languages[language].update(lang_messages)
 
 
-def get_text(text: str, count: Optional[int] = None, language: str = '') -> str:
+def get_text(text: str, count: Optional[int] = None, key_suffix: str = '', language: str = '') -> str:
     """ translate passed text string into the current language.
 
     :param text:        text message to be translated.
     :param count:       pass int value if the translated text has variants for their pluralization.
                         The count value will be converted into an amount/pluralize key by the
                         function :func:`plural_key`.
+    :param key_suffix:  suffix to the key used if the translation is a dict.
     :param language:    language code to load (def=current language code in 1st item of :data:`default_locale`).
     :return:            translated text message or the value passed into :paramref:`~get_text.text`
                         if no translation text got found for the current language.
     """
-    if not language:
-        language = default_locale[0]
-
-    if language in loaded_languages:
-        translations = loaded_languages[language]
-        if text in translations:
-            trans = translations[text]
-            if isinstance(trans, str):
-                text = trans
-            else:
-                key = plural_key(count) if count is not None else 'any'
-                text = trans.get(key, text)
+    trans = translation(text, language=language)
+    if isinstance(trans, str):
+        text = trans
+    elif trans is not None:
+        text = trans.get(plural_key(count) + key_suffix, text)
     return text
 
 
 _ = get_text         #: alias of :func:`get_text`.
 
 
-def get_f_string(f_string: str, count: Optional[int] = None, language: str = '',
+def get_f_string(f_str: str, count: Optional[int] = None, key_suffix: str = '', language: str = '',
                  glo_vars: Optional[Dict[str, Any]] = None, loc_vars: Optional[Dict[str, Any]] = None
                  ) -> str:
     """ translate passed f-string into a message string of the passed / default language.
 
-    :param f_string:    f-string to be translated and evaluated.
+    :param f_str:       f-string to be translated and evaluated.
     :param count:       pass if the translated text changes on pluralization (see :func:`get_text`).
                         If passed then the value of this argument will be provided/overwritten in the
                         globals as a variable with the name `count`.
+    :param key_suffix:  suffix to the key used if the translation is a dict.
     :param language:    language code to load (def=current language code in 1st item of :data:`default_locale`).
     :param glo_vars:    global variables used in the conversion of the f-string expression to a string.
     :param loc_vars:    local variables used in the conversion of the f-string expression to a string.
@@ -211,31 +223,35 @@ def get_f_string(f_string: str, count: Optional[int] = None, language: str = '',
                         All syntax errors and exceptions occurring in the conversion of the f-string will be
                         ignored and the original or translated f_string value will be returned in these cases.
     """
-    f_string = get_text(f_string, count=count, language=language)
+    f_str = get_text(f_str, count=count, key_suffix=key_suffix, language=language)
 
-    if not glo_vars and not loc_vars:
-        glo_vars, loc_vars, _ = stack_variables(max_depth=3)
+    ret = ''
+    if '{' in f_str and '}' in f_str:  # performance optimization: skip f-string evaluation if no placeholders
+        if not glo_vars and not loc_vars:
+            glo_vars, loc_vars, _ = stack_variables(max_depth=3)
 
-    if count is not None:
-        assert isinstance(glo_vars, dict)       # mypy
-        glo_vars['count'] = count
+        if count is not None:
+            if glo_vars is None:
+                glo_vars = dict()
+            glo_vars['count'] = count
 
-    return (
-        '{' in f_string and '}' in f_string
-        and try_eval('f"' + f_string + '"', ignored_exceptions=(Exception, ), glo_vars=glo_vars, loc_vars=loc_vars)) \
-        or f_string
+        ret = try_eval('f"""' + f_str + '"""', ignored_exceptions=(Exception, ), glo_vars=glo_vars, loc_vars=loc_vars)
+
+    return ret or f_str
 
 
 f_ = get_f_string       #: alias of :func:`get_f_string`.
 
 
-def plural_key(count: int) -> str:
+def plural_key(count: Optional[int]) -> str:
     """ convert number in count into a dict key for to access the correct plural form.
 
-    :param count:       number of items used in the current context.
-    :return:            dict key within the MsgType part of the translation data structure.
+    :param count:       number of items used in the current context or None (resulting in empty string).
+    :return:            dict key (prefix) within the MsgType part of the translation data structure.
     """
-    if count == 0:
+    if count is None:
+        key = ''
+    elif count == 0:
         key = 'zero'
     elif count == 1:
         key = 'one'
@@ -247,17 +263,21 @@ def plural_key(count: int) -> str:
     return key
 
 
-def init_installed_languages():
-    """ reset and rescan the configured/supported languages found in the currently set :data:`locale_paths`.
-    """
-    global installed_languages
-    installed_languages *= 0
+def translation(text: str, language: str = '') -> Optional[Union[str, MsgType]]:
+    """ determine translation for passed text string and language.
 
-    for path in locale_paths:
-        if os.path.exists(path):
-            installed_languages.extend(
-                dir_entry.name for dir_entry in os.scandir(path)
-                if dir_entry.is_dir() and os.path.exists(os.path.join(dir_entry.path, MSG_FILE_SUFFIX)))
+    :param text:        text message to be translated.
+    :param language:    language code to load (def=current language code in 1st item of :data:`default_locale`).
+    :return:            None if not found else translation message or dict with plural forms.
+    """
+    if not language:
+        language = default_locale[0]
+
+    if language in loaded_languages:
+        translations = loaded_languages[language]
+        if text in translations:
+            return translations[text]
+    return None
 
 
 # load and set the system/os locale/language/encoding as the app defaults at startup (import)
